/* Go hackerlogo
 * Copyright (C) 2011 Laszlo Simon
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this software; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */
#include "colors.inc"
#include "stones.inc"
#include "woods.inc" 
#include "kayawoodmap.inc"
#include "textures.inc"
#include "functions.inc"
#include "shapes.inc"
#include "glass.inc"
#include "metals.inc"
#include "woods.inc"

#declare Scale               = 500;
#declare Board_width         = 424.2 / Scale;
#declare Board_length        = 454.5 / Scale;
#declare Board_thickness     = 151.5 / Scale;
#declare Line_spacing_width  = 22    / Scale;
#declare Line_spacing_length = 23.7  / Scale;
#declare Line_thickness      = 1     / Scale;
#declare Star_point_diameter = 4     / Scale;
#declare Stone_diameter      = 21.5  / Scale;
#declare Stone_height        = 7.5   / Scale;
#declare Spacing_width = (Board_width - (Line_spacing_width * 19))/2;
#declare Spacing_length = (Board_length - (Line_spacing_length * 19))/2;

#declare convx = function(x) { Spacing_width + (0.5 + x) * Line_spacing_width }
#declare convy = function(y) { Spacing_length + (0.5 + y) * Line_spacing_length }
/*
global_settings {
  subsurface {}
}
*/
#declare gobanwood =
  texture {
    pigment {
      wood
      warp {
        turbulence <0.1,0.05,0.1>
        octaves 5
        lambda 5
        omega 0.3
      }
      scale 0.00175
      color_map {kaya_woodmap}
      ramp_wave scale 153
    }
    finish {specular 1 roughness 0.02}
  }

camera {
  location <0.1, 0.15, 0.0>
  look_at  <0.19, 0.0, 0.17>
// location <0.36, 0.45, 0.2>
// look_at  <0.36, -0.0, 0.3>
}

light_source { 
  <1, 1, 1> color White
  area_light <2, 0, 0>, <0, 0, 2>, 12, 12
}

#macro TexStone(posx,posy,tex)
  #declare r = (Stone_height*Stone_height+Stone_diameter*Stone_diameter) / (4*Stone_height);
  intersection
  {
    sphere {
      < convx(posx), r, convy(posy) >, r
    }
    sphere {
      < convx(posx), Stone_height - r, convy(posy) >, r
    } 
    cylinder {
      < convx(posx), 0, convy(posy) >,
      < convx(posx), Stone_height, convy(posy) >, 0.59*r
    }
    texture { 
     tex 
/*      subsurface { translucency White }
      interior { ior 100 }
    */  }
  }
#end

#macro Stone(posx,posy,side)
  #if (side <= 0)
    TexStone(posx,posy,T_Grnt15)
  #else
    TexStone(posx,posy,T_Stone8)
  #end
#end

box {
  < 0, -Board_thickness, 0>, 
  < Board_width, 0, Board_length>
  texture {
    gobanwood
    //7,13,21,35
    scale 0.4
  }
}

#macro Board_line(posx0,posy0,posx1,posy1)
  box {
    < convx(posx0) - Line_thickness/2, 0, convy(posy0) - Line_thickness/2>
    < convx(posx1) + Line_thickness/2, 0.0001, convy(posy1) + Line_thickness/2>
    texture {
      T_Wood12
      //pigment { color Black }
    }
  }
#end

#macro Board_circle(posx,posy)
  cylinder {
    < convx(posx), 0, convy(posy) >,
    < convx(posx), 0.0001, convy(posy) >,     
    Star_point_diameter            
    texture {
      T_Wood12
    }
  }
#end

#declare i = 0;
#while (i < 19)
  Board_line(0, i, 18, i)
  Board_line(i, 0, i, 19)
  #declare i = i + 1;
#end

#declare i = 3;
#while (i < 19)
  #declare j = 3;
  #while (j < 19)
    Board_circle(i,j)
    #declare j = j + 6;
  #end
  #declare i = i + 6;
#end

#declare shift = 2;

Stone(0.01+shift,0.02+shift,1)
Stone(1.009+shift,0.01+shift,1)
Stone(2.03+shift,0.005+shift,1)
Stone(0.007+shift,1.005+shift,1)
Stone(1.008+shift,2.01+shift,1)
